@@ -15,11 +15,11 @@
 extern CameraThread * cameraThread;
 
 ExtendedSettings::ExtendedSettings(QWidget * parent) : QTabWidget(parent) {
-    //this->tabBar()->setExpanding(TRUE);
-    ignoreSignals = FALSE;
+    //this->tabBar()->setExpanding(true);
+    ignoreSignals = false;
     //QPushButton * quitButton = new QPushButton("X", this);
     //quitButton->setGeometry(800-160, 0, 160, 64);
-    //quitButton->setFlat(TRUE);
+    //quitButton->setFlat(true);
     //QObject::connect(quitButton, SIGNAL(clicked()),
     //                 cameraThread, SLOT(stop()));
                      
@@ -30,10 +30,16 @@ ExtendedSettings::ExtendedSettings(QWidget * parent) : QTabWidget(parent) {
     visLayout->addWidget(intensityHistogram);    
     ruleOfThirds = new QCheckBox("Show rule of thirds guide    ");
     visLayout->addWidget(ruleOfThirds);
+    captureAnimation = new QCheckBox("Show capture animation    ");
+    visLayout->addWidget(captureAnimation);
+    captureSound = new QCheckBox("Play capture sound    ");
+    visLayout->addWidget(captureSound);
+    captureBlink = new QCheckBox("Blink LED on capture    ");
+    visLayout->addWidget(captureBlink);
     
     visLayout->addStretch(1);
     visualization->setLayout(visLayout);
-    this->addTab(visualization, "Visualizations");
+    
 
     QFrame * fileManagement = new QFrame();
     fileManagement->setFrameShape(QFrame::StyledPanel);
@@ -42,7 +48,7 @@ ExtendedSettings::ExtendedSettings(QWidget * parent) : QTabWidget(parent) {
     layout->addWidget(new QLabel("RAW Path:"), row, 0);
     rawPath = new QLineEdit();    
     
-    //rawPath->setAcceptRichText(FALSE);
+    //rawPath->setAcceptRichText(false);
     //rawPath->setMaximumSize(QWIDGETSIZE_MAX, 64);
     layout->addWidget(rawPath, row, 1);
     row++;
@@ -85,8 +91,7 @@ ExtendedSettings::ExtendedSettings(QWidget * parent) : QTabWidget(parent) {
     fileManagement->setLayout(layout);
             
     
-    this->addTab(fileManagement, "File Management");
-
+    
 
     QFrame * aboutFCamera = new QFrame();
     aboutFCamera->setFrameShape(QFrame::StyledPanel);
@@ -104,14 +109,16 @@ ExtendedSettings::ExtendedSettings(QWidget * parent) : QTabWidget(parent) {
     QPushButton * url = new QPushButton("http://fcam.garage.maemo.org");
     QObject::connect(url, SIGNAL(clicked()),
                      this, SLOT(launchBrowserForFCamWebsite()));
-    url->setFlat(TRUE);
+    url->setFlat(true);
     aboutLayout->addStretch(1);
     aboutLayout->addWidget(whatIsFCam);
     aboutLayout->addWidget(url);
     aboutLayout->addStretch(1);    
     aboutFCamera->setLayout(aboutLayout);
-    this->addTab(aboutFCamera, "About FCamera");    
 
+    this->addTab(fileManagement, "File Management");
+    this->addTab(visualization, "Visualizations");
+    this->addTab(aboutFCamera, "About FCamera");    
 
     
     this->refreshWidgetsFromDefaults();
@@ -132,6 +139,12 @@ ExtendedSettings::ExtendedSettings(QWidget * parent) : QTabWidget(parent) {
                     this, SLOT(settingChanged()));
     QObject::connect(ruleOfThirds, SIGNAL(toggled(bool)),
                 this, SLOT(settingChanged()));
+    QObject::connect(captureAnimation, SIGNAL(toggled(bool)),
+                this, SLOT(settingChanged()));
+    QObject::connect(captureSound, SIGNAL(toggled(bool)),
+                this, SLOT(settingChanged()));
+    QObject::connect(captureBlink, SIGNAL(toggled(bool)),
+                this, SLOT(settingChanged()));
     
     QObject::connect(emptyTrashButton, SIGNAL(clicked()),
                      this, SLOT(emptyTrash()));
@@ -154,30 +167,43 @@ void ExtendedSettings::refreshWidgetsFromDefaults(){
         userDefaults["filenameSuffix"] = "timestamp";
     } 
     if (!userDefaults["autosaveJPGs"].valid()) {
-        userDefaults["autosaveJPGs"] = FALSE;
+        userDefaults["autosaveJPGs"] = false;
     }
     if (!userDefaults["intensityHistogram"].valid()){
-        userDefaults["intensityHistogram"] = TRUE;
+        userDefaults["intensityHistogram"] = true;
     }
     if (!userDefaults["ruleOfThirds"].valid()){
-        userDefaults["ruleOfThirds"] = FALSE;
+        userDefaults["ruleOfThirds"] = false;
+    }
+    if (!userDefaults["captureAnimation"].valid()){
+        userDefaults["captureAnimation"] = true;
+    }
+    if (!userDefaults["captureSound"].valid()){
+        userDefaults["captureSound"] = false;
+    }
+    if (!userDefaults["captureBlink"].valid()){
+        userDefaults["captureBlink"] = true;
     }
-    
     // Block signals temporarily so that all the changes get to propagate
-    ignoreSignals = TRUE;
+    ignoreSignals = true;
     
     rawPath->setText(userDefaults["rawPath"].asString().c_str());
     filePrefix->setText(userDefaults["filenamePrefix"].asString().c_str());
     if (userDefaults["filenameSuffix"].asString() == "timestamp") {
-        timestamp->setChecked(TRUE);
+        timestamp->setChecked(true);
     } else {
-        index->setChecked(TRUE);
+        index->setChecked(true);
     }     
     autosaveJPGs->setChecked(userDefaults["autosaveJPGs"].asInt());
     intensityHistogram->setChecked(userDefaults["intensityHistogram"].asInt());
     ruleOfThirds->setChecked(userDefaults["ruleOfThirds"].asInt());
+    captureAnimation->setChecked(userDefaults["captureAnimation"].asInt());
+    captureSound->setChecked(userDefaults["captureSound"].asInt());
+    captureBlink->setChecked(userDefaults["captureBlink"].asInt());
+    
+    
     // Reactivate signals
-    ignoreSignals = FALSE;
+    ignoreSignals = false;
     
     this->updateTrashButtons();
     userDefaults.commit();
@@ -201,7 +227,9 @@ void ExtendedSettings::settingChanged(){
     userDefaults["autosaveJPGs"] = autosaveJPGs->isChecked();
     userDefaults["intensityHistogram"] = intensityHistogram->isChecked();
     userDefaults["ruleOfThirds"] = ruleOfThirds->isChecked();
-
+    userDefaults["captureAnimation"] = captureAnimation->isChecked();
+    userDefaults["captureSound"] = captureSound->isChecked();
+    userDefaults["captureBlink"] = captureBlink->isChecked();
 
     this->updateTrashButtons();
     userDefaults.commit();
@@ -261,16 +289,16 @@ void ExtendedSettings::restoreTrash() {
 
 
 void ExtendedSettings::updateTrashButtons() {
-    restoreTrashButton->setEnabled(FALSE);
-    emptyTrashButton->setEnabled(FALSE);
+    restoreTrashButton->setEnabled(false);
+    emptyTrashButton->setEnabled(false);
     
     UserDefaults &userDefaults = UserDefaults::instance();
     QDir library(userDefaults["rawPath"].asString().c_str());
     QStringList files = library.entryList();
     foreach (QString file, files) {
         if (file.endsWith(".dng.trash")){
-            restoreTrashButton->setEnabled(TRUE);
-            emptyTrashButton->setEnabled(TRUE);
+            restoreTrashButton->setEnabled(true);
+            emptyTrashButton->setEnabled(true);
         }
     }
 }
