@@ -20,7 +20,7 @@ extern CameraThread * cameraThread;
 
 
 ZoomableThumbnail::ZoomableThumbnail(QWidget * parent) : QWidget(parent) {
-    QObject::connect(&IOThread::instance(), SIGNAL(demosaicFinished()),
+    QObject::connect(&IOThread::reader(), SIGNAL(demosaicFinished()),
                      this, SLOT(update()));
     
     QVBoxLayout * layout = new QVBoxLayout();
@@ -208,10 +208,10 @@ ThumbnailView::ThumbnailView(QWidget *parent): QWidget(parent) {
 
     this->setLayout(hLayout);
 
-    QObject::connect(&IOThread::instance(), SIGNAL(saveFinished(ImageItem *)),
+    QObject::connect(&IOThread::writer(), SIGNAL(saveFinished(ImageItem *)),
                      this, SLOT(updateThumbnails()));
 
-    QObject::connect(&IOThread::instance(), SIGNAL(loadFinished(ImageItem *)),
+    QObject::connect(&IOThread::reader(), SIGNAL(loadFinished(ImageItem *)),
                      this, SLOT(updateThumbnails()));
 
     // Make image items for all the existing dng files
@@ -376,7 +376,7 @@ int min3(int a, int b, int c) {
 }
 
 void ThumbnailView::manageMemory() {
-   // printf("about to loadthumbasync(), item name is %s\n", images[current]->fullPath().toStdString().c_str());
+    // printf("about to loadthumbasync(), item name is %s\n", images[current]->fullPath().toStdString().c_str());
     images[current]->loadThumbnailAsync();
     //printf("loadedthumbasync()\n");
     for (int i = 0; i < (int)images.size(); i++) {
@@ -385,13 +385,13 @@ void ThumbnailView::manageMemory() {
                          abs(current - i - images.size()));
         if (delta <= 3 && delta > 0) {
             if (images[i]->thumbnail().valid()) {
-                images[i]->discardFrame();
+                //images[i]->discardFrame();
             } else {
                 images[i]->loadThumbnailAsync();
             }
         } else if (delta > 3) {
-            images[i]->discardFrame();
-            images[i]->discardThumbnail();
+            //images[i]->discardFrame();
+            //images[i]->discardThumbnail();
         }
     }
 }
@@ -401,31 +401,35 @@ void ThumbnailView::trashSelectedPhoto(){
     ImageItem * selectedImage = images[current];
     images.erase(images.begin() + current);
     
-    QDir fileDir("/"); 
-    
-    
-    //fileDir.remove(selectedImage->fullPath());    
-    //fileDir.remove(selectedImage->fullPath() + ".thumb");
+    QDir fileDir("/");        
     
     int copyIndex = 0;
     // An extra bit of filename to make sure the name is unique
-    QString dupeFix;
+
+    QString fullPath = selectedImage->fullPath();
     QString base = selectedImage->fullPath().left(selectedImage->fullPath().count() - 4); // remove the ".dng"
     QString idealName = base + ".dng";
-    while(! fileDir.rename(selectedImage->fullPath().toStdString().c_str(), 
-           (idealName + ".trash").toStdString().c_str())) {
-           idealName = base + QString().sprintf(".%d.dng", ++copyIndex);           
-    }
 
-    fileDir.rename((selectedImage->fullPath() + ".thumb").toStdString().c_str(), 
-            (idealName + ".thumb.trash").toStdString().c_str());    
-    
-    emit imageTrashed();
-    
+    // Nuke the imageitem. We don't just delete it, because it may in
+    // be an iothread queue somewhere.
     selectedImage->discardThumbnail();
     selectedImage->discardFrame();
+
+    int count = 0;
+    while(! fileDir.rename(fullPath.toStdString().c_str(), 
+           (idealName + ".trash").toStdString().c_str())) {
+           idealName = base + QString().sprintf(".%d.dng", ++copyIndex);           
+           count++;
+           if (count == 100) {
+               // ok, something's up with this file. Let's give up and
+               // just hide it in the UI. It'll reappear next time we
+               // load fcamera.
+               std::cerr << "Failed to delete file: " << fullPath.toStdString() << std::endl;
+               break;
+           }
+    }
     
-    
+    emit imageTrashed();    
     
     if (images.empty()) {
         images.push_back(new ImageItem());        
